package cn.fw.dalaran.server.controller.web;

import cn.fw.common.web.annotation.ControllerMethod;
import cn.fw.dalaran.domain.db.config.ValidConfig;
import cn.fw.dalaran.domain.vo.ValidConfigNewVo;
import cn.fw.dalaran.domain.vo.ValidConfigVo;
import cn.fw.dalaran.service.data.ValidConfigNewService;
import cn.fw.dalaran.service.data.ValidConfigService;
import cn.fw.data.base.domain.common.Message;
import cn.fw.security.auth.client.annotation.Authorization;
import cn.fw.security.auth.client.annotation.IgnoreAuth;
import cn.fw.security.auth.client.enums.AuthType;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import javax.validation.constraints.NotNull;
import java.util.List;
import java.util.stream.Collectors;

import static cn.fw.common.web.util.ResultBuilder.success;

/**
 * @author wmy3969
 * @date 2022-1-11 09:51:47
 * @description 数据有效性配置
 */
@Slf4j
@Deprecated
@Validated
@RestController
@RequiredArgsConstructor
@Authorization(AuthType.ERP)
@RequestMapping("/valid/setting")
@IgnoreAuth
public class ValidSettingController {

    private final ValidConfigService validConfigService;
    private final ValidConfigNewService validConfigNewService;

    /**
     * 修改或添加配置
     *
     * @param validConfig 配置参数
     * @return 操作结果
     */
    @Deprecated
    @PostMapping("/saveOrUpdate")
    @ControllerMethod("修改或添加配置")
    public Message<Boolean> saveOrUpdate(@RequestBody @Valid ValidConfigVo validConfig) {
        return success(validConfigService.saveOrUpdate(ValidConfigVo.toDB(validConfig)));
    }

    /**
     * 查询配置列表
     *
     * @param groupId 集团id
     * @return 符合条件的配置列表
     */
    @Deprecated
    @GetMapping("/list")
    @ControllerMethod("查询配置列表")
    public Message<List<ValidConfigVo>> list(@NotNull(message = "请必须指定集团id") Long groupId) {
        return success(validConfigService.lambdaQuery()
                .eq(groupId > 0, ValidConfig::getGroupId, groupId)
                .orderByAsc(ValidConfig::getId)
                .list()
                .stream()
                .map(ValidConfig::toVO)
                .collect(Collectors.toList())
        );
    }

    /**
     * 修改配置
     *
     * @param validConfigNewVo 新的配置参数
     * @return 操作结果
     */
    @PostMapping("/new/update")
    @ControllerMethod("修改配置")
    public Message<Boolean> update(@RequestBody @Valid ValidConfigNewVo validConfigNewVo) {
        return success(validConfigNewService.updateConfig(validConfigNewVo.getDetails()));
    }

    /**
     * 查询配置列表
     *
     * @param configGroupId 所属配置组id
     * @param type          配置类型
     * @return 符合条件的配置列表
     */
    @GetMapping("/new/list")
    @ControllerMethod("查询配置列表")
    public Message<ValidConfigNewVo> list(@NotNull(message = "所属配置组id不能为空") Long configGroupId, @NotNull(message = "请必须指定类型") Integer type) {
        return success(validConfigNewService.queryList(configGroupId, type));
    }

}
