package cn.fw.dalaran.service.biz;

import cn.fw.common.page.AppPage;
import cn.fw.dalaran.common.utils.StringUtils;
import cn.fw.dalaran.domain.db.LivePool;
import cn.fw.dalaran.domain.db.VideoPool;
import cn.fw.dalaran.domain.dto.DelPoolParam;
import cn.fw.dalaran.domain.dto.PoolQueryDTO;
import cn.fw.dalaran.domain.vo.AppPageVO;
import cn.fw.dalaran.domain.vo.LivePoolVO;
import cn.fw.dalaran.domain.vo.VideoPoolVO;
import cn.fw.dalaran.service.data.LivePoolService;
import cn.fw.dalaran.service.data.VideoPoolService;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.Objects;

/**
 * @author kurisu
 * @date 2021-12-20 16:38
 * @description 短视频池和直播池服务
 */
@Service
@Slf4j
@RequiredArgsConstructor
public class PoolBizService {
    private final VideoPoolService videoPoolService;
    private final LivePoolService livePoolService;

    public AppPage<VideoPoolVO> videoList(PoolQueryDTO queryDTO) {
        prepareParams(queryDTO);
        AppPageVO<VideoPoolVO> page = AppPageVO.init(queryDTO);
        final long total = videoPoolService.videoCount(queryDTO);
        if (total <= 0) {
            return page;
        }
        page.setTotal(total);
        List<VideoPoolVO> list = videoPoolService.videoList(queryDTO);
        page.setData(list);
        return page;
    }

    public AppPage<LivePoolVO> liveList(PoolQueryDTO queryDTO) {
        prepareParams(queryDTO);
        AppPageVO<LivePoolVO> page = AppPageVO.init(queryDTO);
        final long total = livePoolService.liveCount(queryDTO);
        if (total <= 0) {
            return page;
        }
        page.setTotal(total);
        List<LivePoolVO> list = livePoolService.liveList(queryDTO);
        page.setData(list);
        return page;
    }

    private void prepareParams(PoolQueryDTO queryVO) {
        if (Objects.nonNull(queryVO.getOrder()) && StringUtils.isValid(queryVO.getOrderAtt())) {
            StringBuilder sb = new StringBuilder();
            sb.append(StringUtils.toColumnName(queryVO.getOrderAtt()).toLowerCase());
            if (queryVO.getOrder() == 1) {
                sb.append(" asc ");
            } else {
                sb.append(" desc ");
            }
            queryVO.setOrderString(sb.toString());
        }
    }

    public boolean delVideo(DelPoolParam param) {
        final String auth = param.getAuth();
        if (Objects.equals(auth, "fw@2017")) {
            return videoPoolService.removeByIds(param.getIds());
        }
        return false;
    }

    public boolean delLive(DelPoolParam param) {
        final String auth = param.getAuth();
        if (Objects.equals(auth, "fw@2017")) {
            return livePoolService.removeByIds(param.getIds());
        }
        return false;
    }

    public boolean updateVideo(VideoPool param) {
        return videoPoolService.updateById(param);
    }

    public boolean updateLive(LivePool param) {
        return livePoolService.updateById(param);
    }
}
